/*-----------------------------------------------------------------------------
 * File: inchworm.C
 * Author: MICROROBOT Company - http://www.microrobot.com
 * Copyright (c) DEC, 2003
 * Function: Servo Motor Control Program
 *
 * PD0~7 : Servo0~7
 * PC0~PC5 : Servo8~13
 * PB1~PB2 : Servo14, 15
 * PB0 : S/W input
 * PB5 : Buzzer
 * Resonator frequency = 8 MHz
 *---------------------------------------------------------------------------*/

#include <avr/io.h>
#include <avr/signal.h>
#include <avr/interrupt.h>

typedef unsigned char byte;
typedef unsigned int word;


/******************* User Define ***************************/
// Servo motor init Pulse value
//ex) " 1500*8 " -> about 1.5msec --> Servo motor position is center
#define SERVO_0		(1400*8)	
#define	SERVO_1		(1500*8)
#define SERVO_2		(1340*8)  
#define SERVO_3		(1500*8)
#define SERVO_4		(1330*8) 
#define SERVO_5		(1500*8)	
#define SERVO_6		(1240*8)
#define SERVO_7		(1500*8)


//1024 --> 1
#define FACTOR_0	1030
#define FACTOR_1	1024
#define FACTOR_2	1100
#define FACTOR_3	1024
#define FACTOR_4	1000
#define FACTOR_5	1024
#define FACTOR_6	930
#define FACTOR_7	1024

#define S0			0x01
#define S1			0x02
#define S2			0x04
#define S3			0x08
#define S4			0x10
#define S5			0x20
#define S6			0x40
#define S7			0x80

#define BUZZER_OFF	sbi(PORTB, 5)
#define BUZZER_ON	cbi(PORTB, 5)
#define LED_OFF	sbi(PORTB, 5)
#define LED_ON	cbi(PORTB, 5)


#define BUZ_DLY0	300
#define BUZ_DLY1	500

volatile int Data[8][5];
#define Pulse(n)	Data[n][0]	// Now pulse value
#define Deg(n)		Data[n][1]	// Want deg
#define Speed(n)	Data[n][2]	// Moving speed value
#define Init(n)		Data[n][3]	// Init pulse value
#define Factor(n)	Data[n][4]	// Factor value
// If speed value is 1, 0.7deg/sec
// Therfore if speed value is 100, 70deg/sec
 
volatile int No=0;
volatile unsigned char Flag_motor=0xff;

#include <init.c>
#include <function.c>
#include <motion.c>
#include <inter.c>

void adjust_mode(void)
{
	until_switch_intput();
	same_absolute_deg(S4|S6, S4, 90, 100);
	same_absolute_deg(S0|S2, S2, 90, 100);
	buzzer();
}

int main(void)
{
	int i;

	system_init();
	buzzer();
	motor_enable();

	sei();					// Global interrupt enable

	if(bit_is_clear(PINB,0))	adjust_mode();

	until_switch_intput();
	delay_1ms(500);

	buzzer();

	delay_1ms(2000);

	while(1)
	{
		for(i=0; i<5; i++)
		{
			creep1_motion(200);
		}

		delay_1ms(1000);
		head_up_motion(100);
		delay_1ms(1000);

		for(i=0; i<5; i++)
		{
			creep2_motion(200);
		}

		delay_1ms(1000);
		tail_up_motion(100);
		delay_1ms(1000);
	}
}

