// init.c
void port_init(void)
{
	outp( 0xfe, DDRB );	//PORTB bit 0 is input, and the rest output
	outp( 0xff, DDRC );	//All PORTC pins are output
	outp( 0xff, DDRD );	//All PORTD pins are output

	outp( 1, PORTB );	//PORTB bit 0 is "1" -> Use the internal pull-up resister
	outp( 0, PORTC );
	outp( 0, PORTD );
}

void motor_init(void)
{
	outp(4, TCCR0);		    // TIMER_0 CK/256 -> 1=32usec

	outp(0, TCCR1A);
	outp(1, TCCR1B);		// CTC1 clear, TIMER_1 CK/1 -> 8=1usec

	outw(OCR1L, 0xffff);	// 0xffff=65535 -> (65535/8)usec=8.192msec
//	outw(OCR1, 71);		// 71 = 8.75usec -> 1deg.
}

void motor_enable(void)
{
	outp(178,TCNT0);		// 256-178=78 -> 78*32usec=2.496msec
	outw(TCNT1L, 0);

	cbi(TIFR, OCF1);		// clear OCIF1 : Output Compare Flag1 clear
	cbi(TIFR, TOV0);
	sbi(TIMSK, OCIE1);		// set OCIE1 : Timer1 Output Compare Interrupt enable

	cbi(TIFR, TOV0);		// clear TOV0 : Timer0 overflow Flag clear
	cbi(TIFR, OCF1);
	sbi(TIMSK, TOIE0);		// set TOIE0 : Timer0 overflow Interrupt enable
}

void motor_disable(void)
{
	outw(TCNT1L,0);
	outp(0,TCNT0);
	outp( 0, PORTD );
	cbi(TIMSK, OCIE1);		// clear OCIE1 : Timer1 Output Compare Interrupt disable
	cbi(TIMSK, TOIE0);		// clear TOIE0 : Timer0 overflow Interrupt disable
}

void motor_zero(void)
{
	int i;

	Init(0)=SERVO_0;
	Init(1)=SERVO_1;
	Init(2)=SERVO_2;
	Init(3)=SERVO_3;
	Init(4)=SERVO_4;
	Init(5)=SERVO_5;
	Init(6)=SERVO_6;
	Init(7)=SERVO_7;

	Factor(0)=FACTOR_0;
	Factor(1)=FACTOR_1;
	Factor(2)=FACTOR_2;
	Factor(3)=FACTOR_3;
	Factor(4)=FACTOR_4;
	Factor(5)=FACTOR_5;
	Factor(6)=FACTOR_6;
	Factor(7)=FACTOR_7;

	for(i=0; i<8; i++) 
	{
		Deg(i)=Speed(i)=0;
		Pulse(i)=Init(i);
	}
}

void system_init(void)
{
	port_init();
	motor_init();
	motor_zero();
}
